@@ -52,7 +52,7 @@ private:
 
     void createBase();
 
-    void createHens();
+    void createHens(bool livewallpaper);
 
     void createButtons();
 
@@ -84,6 +84,10 @@ private:
     int mMaxSpeed;
     QGraphicsItem* mCurrentScreen;
     QTime mLastTimeEggDelivery;
+
+    bool livewallpaper;
+    bool livewallpaper_pause;
+    int livewallpaper_view;
 };
 
 #endif // GAMEWIDGET_H
