@@ -11,7 +11,7 @@ class Hen : public QGraphicsObject, public Touchable
 
 public:
 
-    Hen(Position position);
+    Hen(Position position, bool is_livewallpaper);
 
     void paint ( QPainter * painter, const QStyleOptionGraphicsItem * option, QWidget * widget = 0 );
 
@@ -42,6 +42,7 @@ private:
     QPixmap mPressedPixmap;
     bool mIsPressed;
 
+    bool livewallpaper;
 };
 
 #endif // HEN_H
