@@ -2,6 +2,7 @@
 #include <QGraphicsScene>
 #include <QPainter>
 #include <QGraphicsPixmapItem>
+#include <QCoreApplication>
 #include "textbutton.h"
 #include "roundrectbutton.h"
 
@@ -13,12 +14,15 @@ MainMenuScreen::MainMenuScreen(QGraphicsScene* scene)
 
     RoundRectButton* newGameBtn = createRoundRectButton("New Game",20,300);
     connect(newGameBtn,SIGNAL(clicked()),this,SIGNAL(startNewGame()));
-
-    RoundRectButton* exitBtn  = createRoundRectButton("Exit",20,300);
-    connect(exitBtn,SIGNAL(clicked()),this,SIGNAL(exitGame()));
-
     newGameBtn->setPos(50,350);
-    exitBtn->setPos(800 - 50 - 300,350);
+
+    if(!QCoreApplication::arguments().contains("--livewallpaper")){  
+        RoundRectButton* exitBtn  = createRoundRectButton("Exit",20,300);
+        connect(exitBtn,SIGNAL(clicked()),this,SIGNAL(exitGame()));
+        exitBtn->setPos(800 - 50 - 300,350);
+    }else
+        newGameBtn->setPos(250,350);
+
 }
 
 //void MainMenuScreen::paint ( QPainter * painter, const QStyleOptionGraphicsItem * /*option*/, QWidget * /*widget*/)
