@@ -3,8 +3,9 @@
 #include <QDebug>
 #include <QPainter>
 #include <QGraphicsSceneMouseEvent>
+#include <QCoreApplication>
 
-TextButton::TextButton( const QString& buttonText,int fontSize  )
+TextButton::TextButton( const QString& buttonText,int fontSize)
     :QGraphicsObject(0),mIsPressed(false)
 {
     mTextItem = new QGraphicsTextItem();
@@ -14,6 +15,11 @@ TextButton::TextButton( const QString& buttonText,int fontSize  )
     mTextItem->setFont(font);
     mTextItem->setPlainText( buttonText );
 
+    if(QCoreApplication::arguments().contains("--livewallpaper"))  
+        this->livewallpaper = TRUE;
+    else
+        this->livewallpaper = FALSE;
+
     setPressed(false);
 }
 
@@ -29,6 +35,11 @@ void TextButton::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
     setPressed(true);
     event->accept();
+
+    if (this->livewallpaper) {
+        setPressed(false);
+        emit clicked();
+    }
     //QGraphicsObject::mousePressEvent(event);
 }
 
